/*
 * Copyright 2015 Open Networking Laboratory
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.onosproject.codec.impl;

import org.onosproject.codec.CodecContext;
import org.onosproject.codec.JsonCodec;
import org.onosproject.net.Link;
import org.onosproject.net.Path;

import com.fasterxml.jackson.databind.node.ArrayNode;
import com.fasterxml.jackson.databind.node.ObjectNode;

import static com.google.common.base.Preconditions.checkNotNull;

/**
 * Path JSON codec.
 */
public class PathCodec extends AnnotatedCodec<Path> {
    @Override
    public ObjectNode encode(Path path, CodecContext context) {
        checkNotNull(path, "Path cannot be null");
        JsonCodec<Link> codec = context.codec(Link.class);
        ObjectNode result = context.mapper()
                .createObjectNode()
                .put("cost", path.cost());
        ArrayNode jsonLinks = result.putArray("links");

        for (Link link : path.links()) {
            jsonLinks.add(codec.encode(link, context));
        }

        return annotate(result, path, context);
    }
}
